@@ -18,3 +18,6 @@ def plugin_settings(settings):
     settings.FEATURES["NOTICES_SNOOZE_COUNT_LIMIT"] = settings.ENV_TOKENS.get(
         "NOTICES_SNOOZE_COUNT_LIMIT", settings.FEATURES["NOTICES_SNOOZE_COUNT_LIMIT"]
     )
+    settings.FEATURES["NOTICES_SEGMENT_KEY"] = settings.AUTH_TOKENS.get(
+        "NOTICES_SEGMENT_KEY", settings.FEATURES["NOTICES_SEGMENT_KEY"]
+    )
